==> zio-aws-ec2_2.13-5.17.104.11-sources.jar: zio/aws/ec2/model/StateReason.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StateReason(
    code: Option[String] = None,
    message: Option[String] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.ec2.model.StateReason = {
    import StateReason.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.StateReason
      .builder()
      .optionallyWith(code.map(value => value: java.lang.String))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.StateReason.ReadOnly =
    zio.aws.ec2.model.StateReason.wrap(buildAwsValue())
}
object StateReason {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.StateReason] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.StateReason = zio.aws.ec2.model
      .StateReason(code.map(value => value), message.map(value => value))
    def code: Option[String]
    def message: Option[String]
    def getCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.StateReason
  ) extends zio.aws.ec2.model.StateReason.ReadOnly {
    override val code: Option[String] =
      scala.Option(impl.code()).map(value => value: String)
    override val message: Option[String] =
      scala.Option(impl.message()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.StateReason
  ): zio.aws.ec2.model.StateReason.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.12-sources.jar: zio/aws/ec2/model/StateReason.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StateReason(
    code: Optional[String] = Optional.Absent,
    message: Optional[String] = Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.ec2.model.StateReason = {
    import StateReason.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.StateReason
      .builder()
      .optionallyWith(code.map(value => value: java.lang.String))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.StateReason.ReadOnly =
    zio.aws.ec2.model.StateReason.wrap(buildAwsValue())
}
object StateReason {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.ec2.model.StateReason] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.StateReason = zio.aws.ec2.model
      .StateReason(code.map(value => value), message.map(value => value))
    def code: Optional[String]
    def message: Optional[String]
    def getCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.StateReason
  ) extends zio.aws.ec2.model.StateReason.ReadOnly {
    override val code: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.code())
      .map(value => value: String)
    override val message: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.StateReason
  ): zio.aws.ec2.model.StateReason.ReadOnly = new Wrapper(impl)
}
